'''A Cleric Prestige Class

Code Spells and a link to cleric cast to prestige casting'''

import es, popuplib, dnds, random, math, gamethread
from dnds import dnds

SpellCommands = ['comet', 'vigorus', 'massspell']

def load():
    dnds.addPrestigeClass('Contemplative', 'Cleric', 10)

    for command in SpellCommands:
        if not es.exists('saycommand', command):
            es.regsaycmd(command, 'dnds/SubScripts/Contemplative/%s'%command)
        if not es.exists('clientcommand', command):
            es.regclientcmd(command, 'dnds/SubScripts/Contemplative/%s'%command)
    
    contemplativeinfo = popuplib.create('contemplativeinfo')
    contemplativeinfo.addline('-{ D&D CS:S - Contemplative Info }-')
    contemplativeinfo.addline(' Required Level: 10 ')
    contemplativeinfo.addline(' Full Casting Progression ')
    contemplativeinfo.addline('-> 1. Passive Skills')
    contemplativeinfo.addline('-> 2. Active Spells/Skills')
    contemplativeinfo.addline('-> 8. Back')
    contemplativeinfo.addline('0. Exit')
    contemplativeinfo.submenu(1, 'contemplativepassive')
    contemplativeinfo.submenu(2, 'contemplativespells')
    contemplativeinfo.submenu(8, 'Clericprestigeinfo 1')
    dnds.addPrestigeInformation('Contemplative', 'contemplativeinfo')

    contemplativepassive = popuplib.create('contemplativepassive')
    contemplativepassive.addline('-{ Contemplative Passive Skills }-')
    contemplativepassive.addline(' Lvl 1: Divine Health - Increased health')
    contemplativepassive.addline(' Lvl 3: Divine Wholeness - Regeneration')
    contemplativepassive.addline(' Lvl 7: Divine Soul - Spell Resistance')
    contemplativepassive.addline(' Lvl 10: Mystic Union - Damage Reduction')
    contemplativepassive.addline('-> 8. Back')
    contemplativepassive.addline('0. Exit')
    contemplativepassive.submenu(8, 'contemplativeinfo')

    contemplativespells = popuplib.create('contemplativespells')
    contemplativespells.addline('-{ Contemplative Active Skills }-')
    contemplativespells.addline(' Lvl 2: Cometfall - Damage, stun, and burn your target (comet)')
    contemplativespells.addline(' Lvl 5: Vigorus Circle - AOE Regen for a time (vigorus)')
    contemplativespells.addline(' Lvl 8: Mass Spell Resistance - All allies gain SR for a time (massspell)')
    contemplativespells.addline('-> 8. Back')
    contemplativespells.addline('0. Exit')
    contemplativespells.submenu(8, 'contemplativeinfo')

    contemplativecast = popuplib.create('Contemplativecast')
    contemplativecast.addline('-{ Contemplative Casting XM }-')
    contemplativecast.addline('-> 1. Cometfall (3M)')
    contemplativecast.addline('-> 2. Vigorus Circle (2M))')
    contemplativecast.addline('-> 3. Mass Spell Resistance (2M)')
    contemplativecast.addline('-> 8. Back')
    contemplativecast.addline('0. Exit')
    contemplativecast.submenu(8, 'Clericcast')
    contemplativecast.prepuser = contemplativeCastPrep
    contemplativecast.menuselect = contemplativeCast

def comet():
    userid = es.getcmduserid()
    if dnds.checkSpell(userid, 2, 3, 2, 'Contemplative'):
        dnds.spellDelay(userid, .1)
        es.ServerVar('_dnd_temp%s'%userid).set(0)
        es.server.queuecmd('est_getviewplayer %s _dnd_temp%s'%(userid, userid))
        gamethread.delayed(.1, cometRun, (userid))

def cometRun(userid):
    target = int(es.ServerVar('_dnd_temp%s'%userid))
    if target:
        x1,y1,z1 = es.getplayerlocation(userid)
        x2,y2,z2 = es.getplayerlocation(target)
        if math.sqrt(math.pow(x1-x2,2)+math.pow(y1-y2,2)+math.pow(z1-z2,2)) <= 1500:
            dnds.Beam1(userid, target, 1, 255, 0, 0)
            if not dnds.spellResistance(target, 10+dnds.getLevel(userid, 'Contemplative')):
                dnds.Damage(target, userid, random.randrange(30, 90, 10))
                es.tell(target, '#multi', 'You have been hit by a comet!')
                es.tell(userid, '#multi', 'You have hit %s with a comet'%es.getplayername(target))
                es.server.queuecmd('est_Burn %s %s'%(target, random.randint(2, 7)))
                dnds.Freeze(target, 3)
            dnds.spellDelay(userid, 6)
            Key = dnds.getPlayer(userid)
            Key['spells'][2] -= 3

def vigorus():
    userid = es.getcmduserid()
    Key = dnds.getPlayer(userid)
    if dnds.checkSpell(userid, 2, 3, 5, 'Contemplative'):
        if 'aoe regen' not in Key['buffs']:
            es.tell(userid, '#multi', 'You have a healing aura about you for the next 15 seconds')
            dnds.Buffs(userid, 'aoe regen', 15)
            vigorusLoop(userid)
            dnds.spellDelay(userid, 6)
            Key['spells'][2] -= 2

def vigorusLoop(userid, count=1):
    for player in es.getUseridList():
        x1,y1,z1 = es.getplayerlocation(userid)
        if es.getplayerteam(userid) == es.getplayerteam(player):
            x2,y2,z2 = es.getplayerlocation(player)
            if math.sqrt(math.pow(x1-x2,2)+math.pow(y1-y2,2)+math.pow(z1-z2,2)) <= 360:
                dnds.Heal(player, 2)
    if count < 15:
        dnds.Delayed(userid, 1, vigorusLoop, (userid, count+1))
    else:
        es.tell(userid, '#multi', 'Your vigorus healing aura has worn off...')

def massspell():
    userid = es.getcmduserid()
    Key = dnds.getPlayer(userid)
    if dnds.checkSpell(userid, 2, 3, 8, 'Contemplative'):
        if 'sr' not in Key['buffs']:
            es.tell(userid, '#multi', 'You have granted all nearby allies spell resistance for the next 15 seconds')
            dnds.Buffs(userid, 'sr', 15)
            for player in es.getUseridList():
                x1,y1,z1 = es.getplayerlocation(userid)
                if es.getplayerteam(userid) == es.getplayerteam(player):
                    x2,y2,z2 = es.getplayerlocation(player)
                    if math.sqrt(math.pow(x1-x2,2)+math.pow(y1-y2,2)+math.pow(z1-z2,2)) <= 360:
                        dnds.tempValue(player, 'spell resistance', 20, 15)
                        if player != userid:
                            es.tell(player, '#multi', '%s has granted you spell resistance for the next 15 seconds'%es.getplayername(userid))
                            dnds.giveXp(userid, 5, 'buffing and ally')
                        dnds.Delayed(player, 15, es.tell, (player, '#multi', 'Your spell resistance has worn off...'))
            dnds.spellDelay(userid, 6)
            Key['spells'][2] -= 2

def player_spawn(ev):
    userid = int(ev['userid'])
    Key = dnds.getPlayer(userid)
    if dnds.isPrestige(userid, 'Contemplative'):
        level = dnds.getLevel(userid, 'Contemplative')
        Key['spells'][1] += level
        Key['spells'][2] += level/2
        if level >= 1:
            dnds.Health(userid, 15)
        if level >= 3:
            dnds.Regeneration(userid, 3, 2)
        if level >= 7:
            Key['spell resistance'] += 5+level
        if level >= 10:
            Key['damage reduction'] += .2

def contemplativeCastPrep(userid, popupid):
    popup = popuplib.find(popupid)
    Key = dnds.getPlayer(userid)
    level = dnds.getLevel(userid, 'Contemplative')
    popup.modline(1, '-{ Contemplative Casting %sM }-'%Key['spells'][2])
    if level >= 2:
        if Key['spells'][2] < 3:
            popup.modline(2, ' Cometfall 3M')
        else:
            popup.modline(2, '-> 1. Cometfall 3M')
    else:
        popup.modline(2, '')
    if level >= 5:
        if Key['spells'][2] < 2:
            popup.modline(3, ' Vigorus Circle 2M')
        else:
            popup.modline(3, '-> 2. Vigorus Circle 2M')
    else:
        popup.modline(3, '')
    if level >= 8:
        if Key['spells'][2] < 2:
            popup.modline(4, ' Mass Spell Resistance 2M')
        else:
            popup.modline(4, '-> 3. Mass Spell Resistance 2M')
    else:
        popup.modline(4, '')

def contemplativeCast(userid, choice, popupid):
    if choice == 1:
        es.cexec(userid, 'comet')
    elif choice == 2:
        es.cexec(userid, 'vigorus')
    elif choice == 3:
        es.cexec(userid, 'massspell')

